@@ -18,24 +18,36 @@ add_holidays_mid_term <- function(midterm_data) {
       year <- 2017
       country <- "FR"
       holiday_list <- list()
-      tryCatch(
-        {
-          response <- jsonlite::fromJSON(paste0(
+
+          response <- tryCatch(
+            { jsonlite::fromJSON(paste0(
             "https://date.nager.at/api/v3/publicholidays/",
             year, "/", country
           ))
-          holiday_list[[1]] <- response$date
+
         },
         error = function(e) {
-          stop("Error during JSON request to date.nager.at : ", e$message, call. = FALSE)
+          message("Error during JSON request to date.nager.at : ", e$message)
+          return(NULL)
         }
       )
+          if (is.null(response) || is.null(response$date) || length(response$date) == 0) {
+            message(
+              "Could not verify example via date.nager.at; ",
+              "returning input data unchanged."
+            )
+            return(invisible(midterm_data))
+          }
+
+          holiday_list[[1]] <- response$date
 
       if (holiday_list[[1]][1] == "2017-01-01") {
         return(oRaklE::example_midterm_demand_data)
       }
     } else {
-      stop("The example in add_holidays_mid_term() failed. Please contact the package maintainer at schwenzer@europa-uni.de")
+      stop("The example output of add_holidays_mid_term() did not match the expected output.
+           There might be a change in the API response structure.
+           Please contact the package maintainer at schwenzer@europa-uni.de")
     }
   }
   midterm <- midterm_data
@@ -69,6 +81,9 @@ add_holidays_mid_term <- function(midterm_data) {
   midterm$holiday <- 0
   midterm$holiday[midterm$date %in% holidays] <- 1
 
+  if (all(midterm$holiday == 0)) {
+    message("No matching holidays were returned by the date.nager API. Seems like the API didn't respond. You can try again in 2 minutes.")
+  }
 
   return(midterm)
 }
