@@ -16,26 +16,35 @@ add_holidays_short_term <- function(shortterm) {
       year <- 2017
       country <- "FR"
       holiday_list <- list()
-      tryCatch(
-        {
+
           Sys.sleep(1.5)
-          response <- jsonlite::fromJSON(paste0(
+          response <-      tryCatch(
+            {jsonlite::fromJSON(paste0(
             "https://date.nager.at/api/v3/publicholidays/",
             year, "/", country
           ))
-          holiday_list[[1]] <- response$date
+
         },
         error = function(e) {
-          stop("Error during JSON request to date.nager.at : ", e$message, call. = FALSE)
+          message("Error during JSON request to date.nager.at : ", e$message)
+          return(NULL)
         }
       )
-
+          if (is.null(response) || is.null(response$date) || length(response$date) == 0) {
+            message(
+              "Could not verify example via date.nager.at; ",
+              "returning input data unchanged."
+            )
+            return(invisible(shortterm))
+          }
+      holiday_list[[1]] <- response$date
       if (holiday_list[[1]][1] == "2017-01-01") {
         return(oRaklE::example_shortterm_demand_data)
       }
     } else {
-      stop("The example in add_holidays_short_term() failed. Please contact the package maintainer at schwenzer@europa-uni.de")
-    }
+      stop("The example output of add_holidays_short_term() did not match the expected output.
+           There might be a change in the API response structure.
+           Please contact the package maintainer at schwenzer@europa-uni.de")}
   }
   years <- unique(shortterm$year)
   country <- (unique(shortterm$country))
@@ -64,6 +73,8 @@ add_holidays_short_term <- function(shortterm) {
   holidays <- as.Date(holidays)
 
   shortterm$holiday <- ifelse(as.Date(shortterm$date, tz = "CET") %in% holidays, 1, 0)
-
+  if (all(shortterm$holiday == 0)) {
+    message("No matching holidays were returned by the date.nager API. Seems like the API didn't respond. You can try again in 2 minutes.")
+  }
   return(shortterm)
 }
