@@ -178,6 +178,11 @@ full_forecast <- function(start_year, end_year_data, country, test_set_steps = 2
   message("\nData preparation.")
 
   demand_data <- oRaklE::get_entsoE_data(start_year, end_year_data, country)
+  if (is.null(demand_data) || (is.list(demand_data) && length(demand_data) == 0)) {
+    message("The initial call for the requested load data to Entso-E failed or returned an unusable format. Please check
+            the output of get_entsoE_data() for your parameters.")
+    return(invisible(NULL))
+  }
   suppressMessages(
     demand_data_filled <- oRaklE::fill_missing_data(demand_data, data_directory = data_directory)
   )
@@ -187,9 +192,15 @@ full_forecast <- function(start_year, end_year_data, country, test_set_steps = 2
   message("\nCalculating long-term trend models.")
   longterm <- oRaklE::get_historic_load_data(decomposed_data$longterm)
   longterm_all_data <- oRaklE::get_macro_economic_data(longterm)
+  if (is.null(longterm_all_data) || (is.list(longterm_all_data) && length(longterm_all_data) == 0)) {
+    message("The call for macro economic data to the World Bank failed or returned an unusable format. Please check
+            the output of get_macro_economic_data() for your parameters.")
+    return(invisible(NULL))
+  }
   longterm_all_data_predicted <- oRaklE::long_term_lm(longterm_all_data, test_set_steps = test_set_steps, data_directory = data_directory, verbose = verbose)
   message("\nCalculating mid-term trend models.")
   midterm <- oRaklE::add_holidays_mid_term(decomposed_data$midterm)
+
   suppressMessages(
     midterm_all <- oRaklE::get_weather_data(midterm, data_directory = data_directory)
   )
