@@ -181,18 +181,23 @@ get_entsoE_data <- function(start_year, end_year, country, api_key = "default",
   for (i in start:end) {
     starting_year <- i
     message(paste("Getting data for", i))
-    tryCatch(
-      {
-        entso_response <- httr::GET(paste0("https://web-api.tp.entsoe.eu/api?securityToken=", api_key, "&documentType=A65&processType=A16&outBiddingZone_Domain=", domain, "&periodStart=", starting_year, "01010000&periodEnd=", (starting_year + 1), "01010000"))
+
+        entso_response <- tryCatch(
+          { httr::GET(paste0("https://web-api.tp.entsoe.eu/api?securityToken=", api_key, "&documentType=A65&processType=A16&outBiddingZone_Domain=", domain, "&periodStart=", starting_year, "01010000&periodEnd=", (starting_year + 1), "01010000"))
       },
       error = function(e) {
-        stop("Error during GET request for year ", i, ": ", e$message,
-          "\nAre you connected to the internet?",
-          call. = FALSE
+        message(
+          "Error during GET request for year ", i, ": ",
+          conditionMessage(e),
+          "\nAre you connected to the internet?"
         )
+          return(NULL)
+
       }
     )
-
+    if (is.null(entso_response)) {
+      return(invisible(data_list))
+    }
     if (entso_response$status_code == 503) {
       message("The ENTSO_E Transparency platform seems to be unavailable.\n
               Please check https://transparency.entsoe.eu/ and try again later.")
@@ -205,7 +210,11 @@ get_entsoE_data <- function(start_year, end_year, country, api_key = "default",
     if (httr::http_error(entso_response)) {
       status <- httr::status_code(entso_response)
       error_info <- httr::http_status(entso_response)$message
-      stop("HTTP request failed for year ", i, " (status ", status, "): ", error_info)
+      message(
+        "HTTP request failed for year ", i,
+        " (status ", status, "): ", error_info
+      )
+      return(invisible(data_list))
     }
 
 
@@ -217,18 +226,18 @@ get_entsoE_data <- function(start_year, end_year, country, api_key = "default",
     # The response sends unpredictable numbers of time series, therefore we have to loop
     # over each one.
 
+    periods <- entso_timeseries$TimeSeries[names(entso_timeseries$TimeSeries) == "Period"]
     ts_list <- list()
-    for (j in 1:length(entso_timeseries)) {
-      ts <- entso_timeseries[j]
-      load <- as.numeric(unlist(purrr::map(ts$TimeSeries$Period, "quantity")))
-      start_date <- lubridate::ymd_hm(ts$TimeSeries$Period$timeInterval$start[[1]], tz = "UTC")
-      end_date <- lubridate::ymd_hm(ts$TimeSeries$Period$timeInterval$end[[1]], tz = "UTC")
-      time_resolution <- ts$TimeSeries$Period$resolution
+    for (j in 1:length(periods)) {
+      ts <- periods[j]
+      load <-as.numeric(unlist(purrr::map(ts$Period, "quantity")))
+      start_date <- lubridate::ymd_hm(ts$Period$timeInterval$start[[1]], tz = "UTC")
+      end_date <- lubridate::ymd_hm(ts$Period$timeInterval$end[[1]], tz = "UTC")
+      time_resolution <- ts$Period$resolution
       time_resolution_minutes <- paste(as.integer(substr(time_resolution, 3, 4)), "mins")
-
-      ts_data <- as.data.frame(seq(start_date, end_date, by = time_resolution_minutes))
+      ts_data <- as.data.frame(seq(start_date, by = time_resolution_minutes,length.out = length(load)))
       colnames(ts_data) <- "date"
-      ts_data <- ts_data[-length(ts_data$date), , drop = F]
+
       ts_data$load <- load
 
       ts_list[[j]] <- ts_data
@@ -256,3 +265,6 @@ get_entsoE_data <- function(start_year, end_year, country, api_key = "default",
   }
   return(all_data)
 }
+
+
+
